<?php
/**
* Minify Version 1.0
* 
* Plugin written by Jayhunter for
* 
* Coppermine Photo Gallery
* Coppermine version: 1.5.xx
*
**************************************************
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
**************************************************
*/

if (!defined('IN_COPPERMINE')) die('Not in Coppermine...');
    require_once('plugins/minify/init.inc.php');

// Compress JS files
$thisplugin->add_filter('javascript_includes','minify_javascript_includes_filter');
$thisplugin->add_filter('page_html','minify_page_html_filter');


function minify_page_html_filter ($html) {
    $html = minify_fetch_css($html);
    $html = minify_replace_css($html);
    $html = minify_replace_js_hack($html);
    return $html;
}

function minify_fetch_css ($html) {
    global $CONFIG;

    $prev_conf = $conf = unserialize(minify_get_config('plugin_minify_css_storage'));
    // Get all css files from HTML
    $n = preg_match_all('/href="([^"]+?\.css)"/', $html, $matches);
    if ($n !== FALSE && $n > 0) {
        foreach ($matches[1] AS $key => $value) {
            if (!array_key_exists($value, $conf)) {
                $conf[$value] = array('enabled' => false);
            }
        }
    }
    if ($conf != $prev_conf) {
        minify_write_config('plugin_minify_css_storage', serialize($conf));
    }

    return $html;
}

function minify_replace_css($html) {
    global $CONFIG;

    if (!$CONFIG['plugin_minify_enable_css']) {
        return $html;
    }

    $conf = unserialize(minify_get_config('plugin_minify_css_storage'));
    
    $insert_minifyed = false;
    foreach ($conf AS $key => $values) {
        if ($values['enabled']) {
            $insert_minifyed = true;
            $html = preg_replace('/(<link.+?(' . str_replace('/','\/',$key) . ').+?\/>)/i','',$html);
            //$html .= '/(<link.+?(' . str_replace('/','\/',$key) . ').+?\/>)/i';
        }
    }
    if ($insert_minifyed) {
        $min_file = $CONFIG['ecards_more_pic_target'] . 'plugins/minify/min.php?g=css';
        $html = str_replace('</head>','<link rel="stylesheet" href="' . $min_file . '" type="text/css" /></head>',$html);
        
    }
    return $html;
}



function minify_replace_js_hack($html) {
    global $CONFIG;

    if (!$CONFIG['plugin_minify_enable_js']) {
        return $html;
    }

    $min_file = $CONFIG['ecards_more_pic_target'] . 'plugins/minify/min.php?g=js';
    $html = str_replace('<head>', '<head><script type="text/javascript" src="' . $min_file . '"></script>',$html);
    

    return $html;
}













function minify_javascript_includes_filter ($js) {
    $js = minify_fetch_js($js);
    $js = minify_replace_js($js);
    return $js;
}

function minify_fetch_js($js) {
    global $CONFIG;

    $prev_conf = $conf = unserialize(minify_get_config('plugin_minify_js_storage'));

    foreach ($js AS $key => $file) {
        if (!array_key_exists($file, $conf) && strpos($file, 'min.php')===false) {
            $conf[$file] = array('enabled' => false);
        }
    }
    if ($conf != $prev_conf) {
        minify_write_config('plugin_minify_js_storage', serialize($conf));
    }
    return $js;

}

function minify_replace_js($js) {
    global $CONFIG;
    
    if (!$CONFIG['plugin_minify_enable_js']) {
        return $js;
    }
    $conf = unserialize(minify_get_config('plugin_minify_js_storage'));
    
    $insert_minifyed = false;

    foreach ($js AS $key => $file) {
        if (array_key_exists($file, $conf) && $conf[$file]['enabled']) {
            $insert_minifyed = true;
            unset($js[$key]);
        }
    }
    if ($insert_minifyed) {
        // We do not insert minified file here because it will be ignored by function js_include (no valid file (dooh!))
        //$js[] = $CONFIG['ecards_more_pic_target'] . 'plugins/minify/min.php?g=js';
    }
    
    return $js;
}
























$thisplugin->add_action('plugin_install','minify_install');
$thisplugin->add_action('plugin_uninstall','minify_uninstall');    

// Install the plugin
function minify_install() {
    global $CONFIG, $minify_conf_array;

    $query ="
    CREATE TABLE IF NOT EXISTS `{$CONFIG['TABLE_PREFIX']}plugin_minify_config` (
  `name` varchar(40) NOT NULL DEFAULT '',
  `value` mediumtext NOT NULL,
  PRIMARY KEY (`name`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 COMMENT='Used to store the mionify plugin configuration options';
";
    cpg_db_query($query);


    // This will add all the config values
    $query = "INSERT INTO `{$CONFIG['TABLE_PREFIX']}config` (`name`, `value`) VALUES ";

    if (count($minify_conf_array)) {
        $first = 1;
        foreach ($minify_conf_array as $conf_key => $conf_val) {
            if ($conf_val['type'] == 'separator') continue;
            $query .= ($first?'':',') . "('{$conf_key}', '".addslashes($conf_val['default'])."') ";
            $first = 0;
        }
        $query .= ';';
    }

    if (!$first) {
        cpg_db_query($query);
    }
    
    return true;
}

// Uninstall the plugin
function minify_uninstall() {
    global $CONFIG, $minify_conf_array;

    if (count($minify_conf_array)) {
        // This will delete all the config values
        $query = "DELETE FROM `{$CONFIG['TABLE_PREFIX']}config` ";

        $first = 1;
        foreach ($minify_conf_array as $conf_key => $conf_val) {
            if ($conf_val['type'] == 'separator') continue;
            $query .= ($first?' WHERE ':' OR ') . " 'name'='{$conf_key}' ";
            $first = 0;
        }
        $query .= ';';
    }

    if (!$first) {
        cpg_db_query($query);
    }
    $query ="DROP TABLE `{$CONFIG['TABLE_PREFIX']}plugin_minify_config`;";
    cpg_db_query($query);
    return true;
}            
